pub fn extrinsics_data_root<H>(
    xts: Vec<Vec<u8, Global>, Global>
) -> <H as Hash>::Outputwhere
    H: Hash,
Compute the trie root of a list of extrinsics.

The merkle proof is using the same trie as runtime state with state_version 0.