Struct frame::prelude::frame_system::CheckNonce
pub struct CheckNonce<T>(pub <T as Config>::Nonce)
where
T: Config;Expand description
Nonce check and increment to give replay protection for transactions.
Transaction Validity
This extension affects requires and provides tags of validity, but DOES NOT
set the priority field. Make sure that AT LEAST one of the signed extension sets
some kind of priority upon validating transactions.
Tuple Fields
0: <T as Config>::NonceImplementations
impl<T> CheckNonce<T>where
T: Config,
impl<T> CheckNonce<T>where T: Config,
pub fn from(nonce: <T as Config>::Nonce) -> CheckNonce<T>
pub fn from(nonce: <T as Config>::Nonce) -> CheckNonce<T>
utility constructor. Used only in client/factory code.