Trait frame::prelude::frame_system::ConsumerLimits
pub trait ConsumerLimits {
// Required methods
fn max_consumers() -> u32;
fn max_overflow() -> u32;
}Expand description
Numeric limits over the ability to add a consumer ref using inc_consumers.
Required Methods
fn max_consumers() -> u32
fn max_consumers() -> u32
The number of consumers over which inc_consumers will cease to work.
fn max_overflow() -> u32
fn max_overflow() -> u32
The maximum number of additional consumers expected to be over be added at once using
inc_consumers_without_limit.
Note: This is not enforced and it’s up to the chain’s author to ensure this reflects the actual situation.