Function frame::prelude::frame_system::extrinsics_data_root
pub fn extrinsics_data_root<H>(
xts: Vec<Vec<u8, Global>, Global>
) -> <H as Hash>::Outputwhere
H: Hash,Expand description
Compute the trie root of a list of extrinsics.
The merkle proof is using the same trie as runtime state with
state_version 0.