Function frame::prelude::frame_system::extrinsics_root
pub fn extrinsics_root<H, E>(extrinsics: &[E]) -> <H as Hash>::Outputwhere
H: Hash,
E: Encode,Expand description
Compute the trie root of a list of extrinsics.
The merkle proof is using the same trie as runtime state with
state_version 0.